@@ -1,30 +1,19 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CONFIGUREPLUGINSWIDGET_H
 #define CONFIGUREPLUGINSWIDGET_H
 
-#include <QWidget>
 #include "pimcommon_export.h"
+#include <QWidget>
 class QSplitter;
 class QTextEdit;
 class KMessageWidget;
-namespace PimCommon {
+namespace PimCommon
+{
 class ConfigurePluginsListWidget;
 /**
  * @brief The ConfigurePluginsWidget class
@@ -36,7 +25,7 @@ class PIMCOMMON_EXPORT ConfigurePluginsWidget : public QWidget
 public:
     explicit ConfigurePluginsWidget(QWidget *parent = nullptr);
     explicit ConfigurePluginsWidget(ConfigurePluginsListWidget *configurePluginListWidget, QWidget *parent = nullptr);
-    ~ConfigurePluginsWidget();
+    ~ConfigurePluginsWidget() override;
 
     void save();
     void defaults();
