@@ -12,11 +12,13 @@
 #include "pimcommonakonadi_export.h"
 #include <QDialog>
 
-namespace KLDAP {
+namespace KLDAP
+{
 class LdapClientSearch;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CompletionOrderEditorPrivate;
 /**
  * @brief The CompletionOrderEditor class
@@ -26,8 +28,8 @@ class PIMCOMMONAKONADI_EXPORT CompletionOrderEditor : public QDialog
     Q_OBJECT
 
 public:
-    CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch, QWidget *parent = nullptr);
-    ~CompletionOrderEditor();
+    explicit CompletionOrderEditor(KLDAP::LdapClientSearch *ldapSearch, QWidget *parent = nullptr);
+    ~CompletionOrderEditor() override;
 
 private Q_SLOTS:
     void slotOk();
